==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/DependentStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DependentStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder>{
  public DependentStatusBuilder() {
    this(false);
  }
  public DependentStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new DependentStatus(), validationEnabled);
  }
  public DependentStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public DependentStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DependentStatus(), validationEnabled);
  }
  public DependentStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus instance) {
    this(fluent, instance, false);
  }
  public DependentStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroup(instance.getGroup()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withUuid(instance.getUuid()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DependentStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus instance) {
    this(instance,false);
  }
  public DependentStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withMessage(instance.getMessage()); 
    this.withStatus(instance.getStatus()); 
    this.withUuid(instance.getUuid()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus build() {
    DependentStatus buildable = new DependentStatus(fluent.getGroup(),fluent.getKind(),fluent.getMessage(),fluent.getStatus(),fluent.getUuid(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DependentStatusBuilder that = (DependentStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.2.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/DependentStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DependentStatusBuilder extends DependentStatusFluentImpl<DependentStatusBuilder> implements VisitableBuilder<DependentStatus,DependentStatusBuilder>{
  public DependentStatusBuilder() {
    this(false);
  }
  public DependentStatusBuilder(Boolean validationEnabled) {
    this(new DependentStatus(), validationEnabled);
  }
  public DependentStatusBuilder(DependentStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public DependentStatusBuilder(DependentStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DependentStatus(), validationEnabled);
  }
  public DependentStatusBuilder(DependentStatusFluent<?> fluent,DependentStatus instance) {
    this(fluent, instance, false);
  }
  public DependentStatusBuilder(DependentStatusFluent<?> fluent,DependentStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroup(instance.getGroup()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withUuid(instance.getUuid()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DependentStatusBuilder(DependentStatus instance) {
    this(instance,false);
  }
  public DependentStatusBuilder(DependentStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withMessage(instance.getMessage()); 
    this.withStatus(instance.getStatus()); 
    this.withUuid(instance.getUuid()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DependentStatusFluent<?> fluent;
  Boolean validationEnabled;
  public DependentStatus build() {
    DependentStatus buildable = new DependentStatus(fluent.getGroup(),fluent.getKind(),fluent.getMessage(),fluent.getStatus(),fluent.getUuid(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
